@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: GraphicsUtil.java 603243 2007-12-11 13:49:04Z jeremias $ */
+/* $Id: GraphicsUtil.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.image;
 
@@ -44,15 +44,30 @@ import org.apache.xmlgraphics.image.rendered.BufferedImageCachableRed;
 import org.apache.xmlgraphics.image.rendered.CachableRed;
 import org.apache.xmlgraphics.image.rendered.RenderedImageCachableRed;
 
+// CSOFF: AvoidNestedBlocks
+// CSOFF: ConstantName
+// CSOFF: MethodName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: OneStatementPerLine
+// CSOFF: OperatorWrap
+// CSOFF: StaticVariableName
+// CSOFF: WhitespaceAfter
+// CSOFF: WhitespaceAround
+
 /**
  * Set of utility methods for Graphics.
  * These generally bypass broken methods in Java2D or provide tweaked
  * implementations.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: GraphicsUtil.java 603243 2007-12-11 13:49:04Z jeremias $
+ * @version $Id: GraphicsUtil.java 1345683 2012-06-03 14:50:33Z gadams $
+ *
+ * Originally authored by Thomas DeWeese.
  */
-public class GraphicsUtil {
+public final class GraphicsUtil {
+
+    private GraphicsUtil() {
+    }
 
     public static AffineTransform IDENTITY = new AffineTransform();
 
@@ -295,7 +310,7 @@ public class GraphicsUtil {
         int width  = x1-x0+1;
         int [] data = null;
 
-        for (int y = y0; y <= y1 ; y++)  {
+        for (int y = y0; y <= y1; y++)  {
             data = src.getPixels(x0,y,width,1,data);
             dst.setPixels       (x0,y,width,1,data);
         }
@@ -405,6 +420,10 @@ public class GraphicsUtil {
                                  retDBT.getData(b), offsets[b], len);
                 break;
             }
+            default:
+                throw new
+                    UnsupportedOperationException("unsupported data type: "
+                                                  + srcDB.getDataType());
             }
         }
 
@@ -1106,6 +1125,6 @@ public class GraphicsUtil {
         }
         return alpha;
     }
-    
-    
+
+
 }
