@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PNGImageDecoder.java 959327 2010-06-30 14:25:03Z spepping $ */
+/* $Id: PNGImageDecoder.java 1353184 2012-06-23 19:18:01Z gadams $ */
 
 package org.apache.xmlgraphics.image.codec.png;
 
@@ -51,9 +51,19 @@ import java.util.zip.InflaterInputStream;
 import org.apache.xmlgraphics.image.codec.util.ImageDecoderImpl;
 import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
 import org.apache.xmlgraphics.image.codec.util.SimpleRenderedImage;
+import org.apache.xmlgraphics.image.loader.impl.PNGConstants;
+
+// CSOFF: ConstantName
+// CSOFF: InnerAssignment
+// CSOFF: MethodName
+// CSOFF: MissingSwitchDefault
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NoWhitespaceAfter
+// CSOFF: OperatorWrap
+// CSOFF: WhitespaceAround
 
 /**
- * @version $Id: PNGImageDecoder.java 959327 2010-06-30 14:25:03Z spepping $
+ * @version $Id: PNGImageDecoder.java 1353184 2012-06-23 19:18:01Z gadams $
  */
 public class PNGImageDecoder extends ImageDecoderImpl {
 
@@ -62,6 +72,7 @@ public class PNGImageDecoder extends ImageDecoderImpl {
         super(input, param);
     }
 
+    @Override
     public RenderedImage decodeAsRenderedImage(int page) throws IOException {
         if (page != 0) {
             throw new IOException(PropertyUtil.getString("PNGImageDecoder19"));
@@ -70,101 +81,19 @@ public class PNGImageDecoder extends ImageDecoderImpl {
     }
 }
 
-class PNGChunk {
-    int length;
-    int type;
-    byte[] data;
-    int crc;
-
-    String typeString;
-
-    public PNGChunk(int length, int type, byte[] data, int crc) {
-        this.length = length;
-        this.type = type;
-        this.data = data;
-        this.crc = crc;
-
-        typeString = "";
-        typeString += (char)(type >> 24);
-        typeString += (char)((type >> 16) & 0xff);
-        typeString += (char)((type >> 8) & 0xff);
-        typeString += (char)(type & 0xff);
-    }
-
-    public int getLength() {
-        return length;
-    }
-
-    public int getType() {
-        return type;
-    }
-
-    public String getTypeString() {
-        return typeString;
-    }
-
-    public byte[] getData() {
-        return data;
-    }
-
-    public byte getByte(int offset) {
-        return data[offset];
-    }
-
-    public int getInt1(int offset) {
-        return data[offset] & 0xff;
-    }
-
-    public int getInt2(int offset) {
-        return ((data[offset] & 0xff) << 8) |
-            (data[offset + 1] & 0xff);
-    }
-
-    public int getInt4(int offset) {
-        return ((data[offset] & 0xff) << 24) |
-            ((data[offset + 1] & 0xff) << 16) |
-            ((data[offset + 2] & 0xff) << 8) |
-            (data[offset + 3] & 0xff);
-    }
-
-    public String getString4(int offset) {
-        return  ""
-            + (char)data[offset]
-            + (char)data[offset + 1]
-            + (char)data[offset + 2]
-            + (char)data[offset + 3];
-    }
-
-    public boolean isType(String typeName) {
-        return typeString.equals(typeName);
-    }
-}
-
 /**
  * TO DO:
  *
  * zTXt chunks
  *
  */
-class PNGImage extends SimpleRenderedImage {
-
-    public static final int PNG_COLOR_GRAY = 0;
-    public static final int PNG_COLOR_RGB = 2;
-    public static final int PNG_COLOR_PALETTE = 3;
-    public static final int PNG_COLOR_GRAY_ALPHA = 4;
-    public static final int PNG_COLOR_RGB_ALPHA = 6;
+class PNGImage extends SimpleRenderedImage implements PNGConstants {
 
     private static final String[] colorTypeNames = {
         "Grayscale", "Error", "Truecolor", "Index",
         "Grayscale with alpha", "Error", "Truecolor with alpha"
     };
 
-    public static final int PNG_FILTER_NONE = 0;
-    public static final int PNG_FILTER_SUB = 1;
-    public static final int PNG_FILTER_UP = 2;
-    public static final int PNG_FILTER_AVERAGE = 3;
-    public static final int PNG_FILTER_PAETH = 4;
-
     private int[][] bandOffsets = {
         null,
         { 0 }, // G
@@ -294,7 +223,7 @@ class PNGImage extends SimpleRenderedImage {
     private static final int POST_ADD_GRAY_TRANS_EXP =
         POST_ADD_GRAY_TRANS | POST_EXP_MASK;
 
-    private List streamVec = new ArrayList();
+    private List<InputStream> streamVec = new ArrayList<InputStream>();
     private DataInputStream dataStream;
 
     private int bytesPerPixel; // number of bytes per input pixel
@@ -389,7 +318,7 @@ class PNGImage extends SimpleRenderedImage {
 
         try {
             long magic = distream.readLong();
-            if (magic != 0x89504e470d0a1a0aL) {
+            if (magic != PNG_SIGNATURE) {
                 String msg = PropertyUtil.getString("PNGImageDecoder0");
                 throw new RuntimeException(msg);
             }
@@ -403,58 +332,58 @@ class PNGImage extends SimpleRenderedImage {
             try {
                 PNGChunk chunk;
 
-                String chunkType = getChunkType(distream);
-                if (chunkType.equals("IHDR")) {
-                    chunk = readChunk(distream);
+                String chunkType = PNGChunk.getChunkType(distream);
+                if (chunkType.equals(PNGChunk.ChunkType.IHDR.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_IHDR_chunk(chunk);
-                } else if (chunkType.equals("PLTE")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.PLTE.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_PLTE_chunk(chunk);
-                } else if (chunkType.equals("IDAT")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.IDAT.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     streamVec.add(new ByteArrayInputStream(chunk.getData()));
-                } else if (chunkType.equals("IEND")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.IEND.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_IEND_chunk(chunk);
                     break; // fall through to the bottom
-                } else if (chunkType.equals("bKGD")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.bKGD.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_bKGD_chunk(chunk);
-                } else if (chunkType.equals("cHRM")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.cHRM.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_cHRM_chunk(chunk);
-                } else if (chunkType.equals("gAMA")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.gAMA.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_gAMA_chunk(chunk);
-                } else if (chunkType.equals("hIST")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.hIST.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_hIST_chunk(chunk);
-                } else if (chunkType.equals("iCCP")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.iCCP.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_iCCP_chunk(chunk);
-                } else if (chunkType.equals("pHYs")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.pHYs.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_pHYs_chunk(chunk);
-                } else if (chunkType.equals("sBIT")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.sBIT.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_sBIT_chunk(chunk);
-                } else if (chunkType.equals("sRGB")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.sRGB.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_sRGB_chunk(chunk);
-                } else if (chunkType.equals("tEXt")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.tEXt.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_tEXt_chunk(chunk);
-                } else if (chunkType.equals("tIME")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.tIME.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_tIME_chunk(chunk);
-                } else if (chunkType.equals("tRNS")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.tRNS.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_tRNS_chunk(chunk);
-                } else if (chunkType.equals("zTXt")) {
-                    chunk = readChunk(distream);
+                } else if (chunkType.equals(PNGChunk.ChunkType.zTXt.name())) {
+                    chunk = PNGChunk.readChunk(distream);
                     parse_zTXt_chunk(chunk);
                 } else {
-                    chunk = readChunk(distream);
+                    chunk = PNGChunk.readChunk(distream);
                     // Output the chunk data in raw form
 
                     String type = chunk.getTypeString();
@@ -488,40 +417,6 @@ class PNGImage extends SimpleRenderedImage {
         }
     }
 
-    private static String getChunkType(DataInputStream distream) {
-        try {
-            distream.mark(8);
-            /* int length = */ distream.readInt();
-            int type      =    distream.readInt();
-            distream.reset();
-
-            String typeString = "";        // todo simplify this
-            typeString += (char)(type >> 24);
-            typeString += (char)((type >> 16) & 0xff);
-            typeString += (char)((type >> 8) & 0xff);
-            typeString += (char)(type & 0xff);
-            return typeString;
-        } catch (Exception e) {
-            e.printStackTrace();
-            return null;
-        }
-    }
-
-    private static PNGChunk readChunk(DataInputStream distream) {
-        try {
-            int length = distream.readInt();
-            int type = distream.readInt();
-            byte[] data = new byte[length];
-            distream.readFully(data);
-            int crc = distream.readInt();
-
-            return new PNGChunk(length, type, data, crc);
-        } catch (Exception e) {
-            e.printStackTrace();
-            return null;
-        }
-    }
-
     private void parse_IHDR_chunk(PNGChunk chunk) {
         tileWidth = width = chunk.getInt4(0);
         tileHeight = height = chunk.getInt4(4);
@@ -1220,21 +1115,21 @@ class PNGImage extends SimpleRenderedImage {
     }
 
     private void parse_tEXt_chunk(PNGChunk chunk) {
-        String key = "";   // todo simplify this
-        String value = ""; // todo simplify this
-        byte b;
 
+        byte b;
+        StringBuffer key = new StringBuffer();
         int textIndex = 0;
         while ((b = chunk.getByte(textIndex++)) != 0) {
-            key += (char)b;
+            key.append( (char)b );
         }
 
+        StringBuilder value = new StringBuilder();
         for (int i = textIndex; i < chunk.getLength(); i++) {
-            value += (char)chunk.getByte(i);
+            value.append((char)chunk.getByte(i));
         }
 
-        textKeys.add(key);
-        textStrings.add(value);
+        textKeys.add(key.toString());
+        textStrings.add(value.toString());
     }
 
     private void parse_tIME_chunk(PNGChunk chunk) {
@@ -1339,16 +1234,16 @@ class PNGImage extends SimpleRenderedImage {
     }
 
     private void parse_zTXt_chunk(PNGChunk chunk) {
-        String key = "";    // todo simplify this
-        String value = "";  // todo simplify this
-        byte b;
 
         int textIndex = 0;
+        StringBuffer key = new StringBuffer();
+        byte b;
         while ((b = chunk.getByte(textIndex++)) != 0) {
-            key += (char)b;
+            key.append( (char)b );
         }
         /* int method = */ chunk.getByte(textIndex++);
 
+        StringBuffer value = new StringBuffer();
         try {
             int length = chunk.getLength() - textIndex;
             byte[] data = chunk.getData();
@@ -1358,11 +1253,11 @@ class PNGImage extends SimpleRenderedImage {
 
             int c;
             while ((c = iis.read()) != -1) {
-                value += (char)c;
+                value.append((char)c);
             }
 
-            ztextKeys.add(key);
-            ztextStrings.add(value);
+            ztextKeys.add(key.toString());
+            ztextStrings.add(value.toString());
         } catch (Exception e) {
             e.printStackTrace();
         }
@@ -1445,21 +1340,6 @@ class PNGImage extends SimpleRenderedImage {
         }
     }
 
-    private static int paethPredictor(int a, int b, int c) {
-        int p = a + b - c;
-        int pa = Math.abs(p - a);
-        int pb = Math.abs(p - b);
-        int pc = Math.abs(p - c);
-
-        if ((pa <= pb) && (pa <= pc)) {
-            return a;
-        } else if (pb <= pc) {
-            return b;
-        } else {
-            return c;
-        }
-    }
-
     private static void decodePaethFilter(byte[] curr, byte[] prev,
                                           int count, int bpp) {
         int raw, priorPixel, priorRow, priorRowPixel;
@@ -1477,7 +1357,7 @@ class PNGImage extends SimpleRenderedImage {
             priorRow = prev[i] & 0xff;
             priorRowPixel = prev[i - bpp] & 0xff;
 
-            curr[i] = (byte)(raw + paethPredictor(priorPixel,
+            curr[i] = (byte)(raw + PNGEncodeParam.paethPredictor(priorPixel,
                                                   priorRow,
                                                   priorRowPixel));
         }
