@@ -15,12 +15,10 @@
  * limitations under the License.
  */
 
-/* $Id: PNGImageEncoder.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: PNGImageEncoder.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.image.codec.png;
 
-import org.apache.xmlgraphics.image.codec.util.ImageEncoderImpl;
-
 import java.awt.Rectangle;
 import java.awt.image.ColorModel;
 import java.awt.image.IndexColorModel;
@@ -40,7 +38,20 @@ import java.util.TimeZone;
 import java.util.zip.Deflater;
 import java.util.zip.DeflaterOutputStream;
 
-class CRC {
+import org.apache.xmlgraphics.image.codec.util.ImageEncoderImpl;
+import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
+
+// CSOFF: ConstantName
+// CSOFF: InnerAssignment
+// CSOFF: LocalVariableName
+// CSOFF: MissingSwitchDefault
+// CSOFF: OperatorWrap
+// CSOFF: WhitespaceAround
+
+final class CRC {
+
+    private CRC() {
+    }
 
     private static int[] crcTable = new int[256];
 
@@ -78,21 +89,24 @@ class ChunkStream extends OutputStream implements DataOutput {
     private ByteArrayOutputStream baos;
     private DataOutputStream dos;
 
-    public ChunkStream(String type) throws IOException {
+    ChunkStream(String type) throws IOException {
         this.type = type;
 
         this.baos = new ByteArrayOutputStream();
         this.dos = new DataOutputStream(baos);
     }
 
+    @Override
     public void write(byte[] b) throws IOException {
         dos.write(b);
     }
 
+    @Override
     public void write(byte[] b, int off, int len) throws IOException {
         dos.write(b, off, len);
     }
 
+    @Override
     public void write(int b) throws IOException {
         dos.write(b);
     }
@@ -163,17 +177,31 @@ class ChunkStream extends OutputStream implements DataOutput {
         crc = CRC.updateCRC(crc, data, 0, len);
         output.writeInt(crc ^ 0xffffffff);
     }
+
+    /** {@inheritDoc} */
+    @Override
+    public void close() throws IOException {
+
+        if ( baos != null ) {
+            baos.close();
+            baos = null;
+        }
+        if (dos != null) {
+            dos.close();
+            dos = null;
+        }
+    }
 }
 
 
 class IDATOutputStream extends FilterOutputStream {
 
-    private static final byte[] typeSignature =
-      {(byte)'I', (byte)'D', (byte)'A', (byte)'T'};
+    private static final byte[] typeSignature
+         = {(byte)'I', (byte)'D', (byte)'A', (byte)'T'};
 
     private int bytesWritten = 0;
     private int segmentLength;
-    byte[] buffer;
+    private byte[] buffer;
 
     public IDATOutputStream(OutputStream output,
                             int segmentLength) {
@@ -182,6 +210,7 @@ class IDATOutputStream extends FilterOutputStream {
         this.buffer = new byte[segmentLength];
     }
 
+    @Override
     public void close() throws IOException {
         flush();
     }
@@ -193,7 +222,12 @@ class IDATOutputStream extends FilterOutputStream {
         out.write(x & 0xff);
     }
 
+    @Override
     public void flush() throws IOException {
+        if (bytesWritten == 0) {
+            return;
+        }
+
         // Length
         writeInt(bytesWritten);
         // 'IDAT' signature
@@ -212,10 +246,12 @@ class IDATOutputStream extends FilterOutputStream {
         bytesWritten = 0;
     }
 
+    @Override
     public void write(byte[] b) throws IOException {
         this.write(b, 0, b.length);
     }
 
+    @Override
     public void write(byte[] b, int off, int len) throws IOException {
         while (len > 0) {
             int bytes = Math.min(segmentLength - bytesWritten, len);
@@ -230,6 +266,7 @@ class IDATOutputStream extends FilterOutputStream {
         }
     }
 
+    @Override
     public void write(int b) throws IOException {
         buffer[bytesWritten++] = (byte)b;
         if (bytesWritten == segmentLength) {
@@ -305,6 +342,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
         cs.writeByte(interlace ? (byte)1 : (byte)0);
 
         cs.writeToStream(dataOutput);
+        cs.close();
     }
 
     private byte[] prevRow = null;
@@ -483,12 +521,15 @@ public class PNGImageEncoder extends ImageEncoderImpl {
         }
 
         dos.finish();
+        dos.close();
         ios.flush();
+        ios.close();
     }
 
     private void writeIEND() throws IOException {
         ChunkStream cs = new ChunkStream("IEND");
         cs.writeToStream(dataOutput);
+        cs.close();
     }
 
     private static final float[] srgbChroma = {
@@ -510,6 +551,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                 cs.writeInt((int)(chroma[i]*100000));
             }
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -527,6 +569,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             // everything is different.
             cs.writeInt((int)(gamma*100000/*+0.5*/));
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -536,6 +579,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             byte[] ICCProfileData = param.getICCProfileData();
             cs.write(ICCProfileData);
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -548,6 +592,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                 cs.writeByte(significantBits[i]);
             }
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -558,6 +603,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             int intent = param.getSRGBIntent();
             cs.write(intent);
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -574,6 +620,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
         }
 
         cs.writeToStream(dataOutput);
+        cs.close();
     }
 
     private void writeBKGD() throws IOException {
@@ -603,6 +650,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             }
 
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -616,6 +664,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             }
 
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -642,6 +691,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             }
 
             cs.writeToStream(dataOutput);
+            cs.close();
         } else if (colorType == PNG_COLOR_PALETTE) {
             int lastEntry = Math.min(255, alphaPalette.length - 1);
             int nonOpaque;
@@ -657,6 +707,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                     cs.writeByte(alphaPalette[i]);
                 }
                 cs.writeToStream(dataOutput);
+                cs.close();
             }
         }
     }
@@ -671,6 +722,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             cs.writeByte((byte)dims[2]);
 
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -681,6 +733,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             System.out.println("sPLT not supported yet.");
 
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -709,6 +762,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             cs.writeByte(second);
 
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -727,6 +781,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                 cs.write(value);
 
                 cs.writeToStream(dataOutput);
+                cs.close();
             }
         }
     }
@@ -748,8 +803,10 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                 DeflaterOutputStream dos = new DeflaterOutputStream(cs);
                 dos.write(value);
                 dos.finish();
+                dos.close();
 
                 cs.writeToStream(dataOutput);
+                cs.close();
             }
         }
     }
@@ -763,6 +820,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             ChunkStream cs = new ChunkStream(type);
             cs.write(data);
             cs.writeToStream(dataOutput);
+            cs.close();
         }
     }
 
@@ -814,6 +872,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
      * the end of the operation, this should be done if needed
      * by the caller of this method.
      */
+    @Override
     public void encode(RenderedImage im) throws IOException {
         this.image = im;
         this.width = image.getWidth();
@@ -847,7 +906,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             // Ensure all channels have the same bit depth
             for (int i = 1; i < sampleSize.length; i++) {
                 if (sampleSize[i] != bitDepth) {
-                    throw new RuntimeException();
+                    throw new RuntimeException(PropertyUtil.getString("PNGImageEncoder0"));
                 }
             }
 
@@ -859,7 +918,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
             } else if (bitDepth > 8 && bitDepth < 16) {
                 bitDepth = 16;
             } else if (bitDepth > 16) {
-                throw new RuntimeException();
+                throw new RuntimeException(PropertyUtil.getString("PNGImageEncoder1"));
             }
         }
 
@@ -869,10 +928,10 @@ public class PNGImageEncoder extends ImageEncoderImpl {
         ColorModel colorModel = image.getColorModel();
         if (colorModel instanceof IndexColorModel) {
             if (bitDepth < 1 || bitDepth > 8) {
-                throw new RuntimeException();
+                throw new RuntimeException(PropertyUtil.getString("PNGImageEncoder2"));
             }
             if (sampleModel.getNumBands() != 1) {
-                throw new RuntimeException();
+                throw new RuntimeException(PropertyUtil.getString("PNGImageEncoder3"));
             }
 
             IndexColorModel icm = (IndexColorModel)colorModel;
@@ -922,7 +981,7 @@ public class PNGImageEncoder extends ImageEncoderImpl {
                 redPalette = greenPalette = bluePalette = alphaPalette = null;
                 this.colorType = PNG_COLOR_GRAY;
             } else {
-                throw new RuntimeException();
+                throw new RuntimeException(PropertyUtil.getString("PNGImageEncoder4"));
             }
         } else if (numBands == 1) {
             if (param == null) {
@@ -998,5 +1057,6 @@ public class PNGImageEncoder extends ImageEncoderImpl {
         writeIEND();
 
         dataOutput.flush();
+        dataOutput.close();
     }
 }
