@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: TIFFDirectory.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: TIFFDirectory.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.image.codec.tiff;
 
@@ -27,8 +27,19 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
 import org.apache.xmlgraphics.image.codec.util.SeekableStream;
 
+// CSOFF: ConstantName
+// CSOFF: EmptyStatement
+// CSOFF: InnerAssignment
+// CSOFF: LocalVariableName
+// CSOFF: MemberName
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: NeedBraces
+// CSOFF: ParameterName
+// CSOFF: WhitespaceAround
+
 /**
  * A class representing an Image File Directory (IFD) from a TIFF 6.0
  * stream.  The TIFF file format is described in more detail in the
@@ -49,9 +60,9 @@ import org.apache.xmlgraphics.image.codec.util.SeekableStream;
  * be removed or changed in future releases of JAI.</b>
  *
  * @see TIFFField
- * @version $Id: TIFFDirectory.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: TIFFDirectory.java 1345683 2012-06-03 14:50:33Z gadams $
  */
-public class TIFFDirectory extends Object implements Serializable {
+public class TIFFDirectory implements Serializable {
 
     /** A boolean storing the endianness of the stream. */
     boolean isBigEndian;
@@ -98,15 +109,13 @@ public class TIFFDirectory extends Object implements Serializable {
         stream.seek(0L);
         int endian = stream.readUnsignedShort();
         if (!isValidEndianTag(endian)) {
-            throw new
-                IllegalArgumentException("TIFFDirectory1");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory1"));
         }
         isBigEndian = (endian == 0x4d4d);
 
         int magic = readUnsignedShort(stream);
         if (magic != 42) {
-            throw new
-                IllegalArgumentException("TIFFDirectory2");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory2"));
         }
 
         // Get the initial ifd offset as an unsigned int (using a long)
@@ -114,8 +123,7 @@ public class TIFFDirectory extends Object implements Serializable {
 
         for (int i = 0; i < directory; i++) {
             if (ifd_offset == 0L) {
-                throw new
-                   IllegalArgumentException("TIFFDirectory3");
+                throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory3"));
             }
 
             stream.seek(ifd_offset);
@@ -125,8 +133,7 @@ public class TIFFDirectory extends Object implements Serializable {
             ifd_offset = readUnsignedInt(stream);
         }
         if (ifd_offset == 0L) {
-            throw new
-               IllegalArgumentException("TIFFDirectory3");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory3"));
         }
 
         stream.seek(ifd_offset);
@@ -154,8 +161,7 @@ public class TIFFDirectory extends Object implements Serializable {
         stream.seek(0L);
         int endian = stream.readUnsignedShort();
         if (!isValidEndianTag(endian)) {
-            throw new
-                IllegalArgumentException("TIFFDirectory1");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory1"));
         }
         isBigEndian = (endian == 0x4d4d);
 
@@ -227,8 +233,7 @@ public class TIFFDirectory extends Object implements Serializable {
                     stream.seek(value);
                 }
             } catch (ArrayIndexOutOfBoundsException ae) {
-
-                System.err.println(tag + " " + "TIFFDirectory4");
+                // System.err.println(tag + " " + "TIFFDirectory4"); TODO - log this message
                 // if the data type is unknown we should skip this TIFF Field
                 stream.seek(nextTagOffset);
                 continue;
@@ -338,8 +343,7 @@ public class TIFFDirectory extends Object implements Serializable {
                 break;
 
             default:
-                System.err.println("TIFFDirectory0");
-                break;
+                throw new RuntimeException(PropertyUtil.getString("TIFFDirectory0"));
             }
 
             fields[i] = new TIFFField(tag, type, count, obj);
@@ -580,14 +584,12 @@ public class TIFFDirectory extends Object implements Serializable {
         stream.seek(0L);
         int endian = stream.readUnsignedShort();
         if (!isValidEndianTag(endian)) {
-            throw new
-                IllegalArgumentException("TIFFDirectory1");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory1"));
         }
         boolean isBigEndian = (endian == 0x4d4d);
         int magic = readUnsignedShort(stream, isBigEndian);
         if (magic != 42) {
-            throw new
-                IllegalArgumentException("TIFFDirectory2");
+            throw new IllegalArgumentException(PropertyUtil.getString("TIFFDirectory2"));
         }
 
         stream.seek(4L);
