@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: TIFFImageDecoder.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: TIFFImageDecoder.java 1311522 2012-04-09 23:37:59Z gadams $ */
 
 package org.apache.xmlgraphics.image.codec.tiff;
 
@@ -24,6 +24,7 @@ import java.io.IOException;
 
 import org.apache.xmlgraphics.image.codec.util.ImageDecodeParam;
 import org.apache.xmlgraphics.image.codec.util.ImageDecoderImpl;
+import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
 import org.apache.xmlgraphics.image.codec.util.SeekableStream;
 
 /**
@@ -71,6 +72,8 @@ public class TIFFImageDecoder extends ImageDecoderImpl {
     public static final int TIFF_S_MIN_SAMPLE_VALUE         = 340;
     public static final int TIFF_S_MAX_SAMPLE_VALUE         = 341;
 
+    public static final int TIFF_ICC_PROFILE                = 34675;
+
     public TIFFImageDecoder(SeekableStream input,
                             ImageDecodeParam param) {
         super(input, param);
@@ -82,7 +85,7 @@ public class TIFFImageDecoder extends ImageDecoderImpl {
 
     public RenderedImage decodeAsRenderedImage(int page) throws IOException {
         if  ((page < 0) || (page >= getNumPages())) {
-            throw new IOException("TIFFImageDecoder0");
+            throw new IOException(PropertyUtil.getString("TIFFImageDecoder0"));
         }
         return new TIFFImage(input, (TIFFDecodeParam)param, page);
     }
