@@ -15,14 +15,20 @@
  * limitations under the License.
  */
 
-/* $Id: TIFFLZWDecoder.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: TIFFLZWDecoder.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.image.codec.tiff;
 
+import org.apache.xmlgraphics.image.codec.util.PropertyUtil;
+
+// CSOFF: InnerAssignment
+// CSOFF: MultipleVariableDeclarations
+// CSOFF: OneStatementPerLine
+// CSOFF: OperatorWrap
+// CSOFF: WhitespaceAround
+
 /**
  * A class for performing LZW decoding.
- *
- *
  */
 public class TIFFLZWDecoder {
 
@@ -60,7 +66,7 @@ public class TIFFLZWDecoder {
     public byte[] decode(byte[] data, byte[] uncompData, int h) {
 
         if(data[0] == (byte)0x00 && data[1] == (byte)0x01) {
-            throw new UnsupportedOperationException("TIFFLZWDecoder0");
+            throw new UnsupportedOperationException(PropertyUtil.getString("TIFFLZWDecoder0"));
         }
 
         initializeStringTable();
