@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PreloaderTIFF.java 925297 2010-03-19 16:11:15Z jeremias $ */
+/* $Id: PreloaderTIFF.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.image.loader.impl;
 
@@ -116,7 +116,8 @@ public class PreloaderTIFF extends AbstractImagePreloader {
                 unit = (int)dir.getFieldAsLong(TIFFImageDecoder.TIFF_RESOLUTION_UNIT);
             }
             if (unit == 2 || unit == 3) {
-                float xRes, yRes;
+                float xRes;
+                float yRes;
                 TIFFField fldx = dir.getField(TIFFImageDecoder.TIFF_X_RESOLUTION);
                 TIFFField fldy = dir.getField(TIFFImageDecoder.TIFF_Y_RESOLUTION);
                 if (fldx == null || fldy == null) {
@@ -127,7 +128,10 @@ public class PreloaderTIFF extends AbstractImagePreloader {
                     xRes = fldx.getAsFloat(0);
                     yRes = fldy.getAsFloat(0);
                 }
-                if (unit == 2) {
+                if (xRes == 0 || yRes == 0) {
+                    //Some TIFFs may report 0 here which would lead to problems
+                    size.setResolution(context.getSourceResolution());
+                } else if (unit == 2) {
                     size.setResolution(xRes, yRes); //Inch
                 } else {
                     size.setResolution(
