@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PNGImageWriter.java 734420 2009-01-14 15:38:32Z maxberger $ */
+/* $Id: PNGImageWriter.java 1345751 2012-06-03 19:47:56Z gadams $ */
 
 package org.apache.xmlgraphics.image.writer.internal;
 
@@ -25,37 +25,30 @@ import java.io.OutputStream;
 
 import org.apache.xmlgraphics.image.codec.png.PNGImageEncoder;
 import org.apache.xmlgraphics.image.writer.AbstractImageWriter;
-import org.apache.xmlgraphics.image.writer.ImageWriter;
 import org.apache.xmlgraphics.image.writer.ImageWriterParams;
 
 /**
  * ImageWriter implementation that uses the internal PNG codec to
  * write PNG files.
  *
- * @version $Id: PNGImageWriter.java 734420 2009-01-14 15:38:32Z maxberger $
+ * @version $Id: PNGImageWriter.java 1345751 2012-06-03 19:47:56Z gadams $
  */
 public class PNGImageWriter extends AbstractImageWriter {
 
-    /**
-     * @see ImageWriter#writeImage(java.awt.image.RenderedImage, java.io.OutputStream)
-     */
+    /** {@inheritDoc} */
     public void writeImage(RenderedImage image, OutputStream out)
             throws IOException {
         writeImage(image, out, null);
     }
 
-    /**
-     * @see ImageWriter#writeImage(java.awt.image.RenderedImage, java.io.OutputStream, ImageWriterParams)
-     */
+    /** {@inheritDoc} */
     public void writeImage(RenderedImage image, OutputStream out,
             ImageWriterParams params) throws IOException {
         PNGImageEncoder encoder = new PNGImageEncoder(out, null);
         encoder.encode(image);
     }
 
-    /**
-     * @see ImageWriter#getMIMEType()
-     */
+    /** {@inheritDoc} */
     public String getMIMEType() {
         return "image/png";
     }
