@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractGraphics2D.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: AbstractGraphics2D.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.java2d;
 
@@ -47,6 +47,10 @@ import java.awt.image.ImageObserver;
 import java.text.AttributedCharacterIterator;
 import java.util.Map;
 
+// CSOFF: NeedBraces
+// CSOFF: ParameterName
+// CSOFF: WhitespaceAround
+
 /**
  * This extension of the <tt>java.awt.Graphics2D</tt> abstract class
  * is still abstract, but it implements a lot of the <tt>Graphics2D</tt>
@@ -62,9 +66,10 @@ import java.util.Map;
  * <tt>drawRect</tt> can be expressed as <tt>draw(new Rectangle(..))</tt>),
  * are implemented by <tt>AbstractGraphics2D</tt>
  *
- * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
- * @version $Id: AbstractGraphics2D.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: AbstractGraphics2D.java 1345683 2012-06-03 14:50:33Z gadams $
  * @see org.apache.xmlgraphics.java2d.GraphicContext
+ *
+ * Originally authored by Vincent Hardy.
  */
 public abstract class AbstractGraphics2D extends Graphics2D implements Cloneable {
     /**
@@ -906,14 +911,13 @@ public abstract class AbstractGraphics2D extends Graphics2D implements Cloneable
             }   catch(NoninvertibleTransformException e){
                                 // Should never happen since we checked the
                                 // matrix determinant
-                throw new Error();
+                throw new RuntimeException(e);
             }
 
             gc.transform(xform);
             retVal = drawImage(img, 0, 0, null);
             gc.transform(inverseTransform);
-        }
-        else{
+        } else {
             AffineTransform savTransform = new AffineTransform(gc.getTransform());
             gc.transform(xform);
             retVal = drawImage(img, 0, 0, null);
