@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PSFontUtils.java 641399 2008-03-26 16:54:02Z jeremias $ */
+/* $Id: PSFontUtils.java 1345763 2012-06-03 20:16:37Z gadams $ */
 
 package org.apache.xmlgraphics.ps;
 
@@ -30,11 +30,16 @@ import org.apache.xmlgraphics.fonts.Glyphs;
 import org.apache.xmlgraphics.util.io.ASCIIHexOutputStream;
 import org.apache.xmlgraphics.util.io.SubInputStream;
 
+// CSOFF: HideUtilityClassConstructor
+
 /**
  * Utility code for font handling in PostScript.
  */
 public class PSFontUtils {
 
+    public PSFontUtils() {
+    }
+
     /**
      * This method reads a Type 1 font from a stream and embeds it into a PostScript stream.
      * Note: Only the IBM PC Format as described in section 3.3 of the Adobe Technical Note #5040
@@ -88,7 +93,7 @@ public class PSFontUtils {
     /** the PSResource representing the WinAnsiEncoding. */
     public static final PSResource WINANSI_ENCODING_RESOURCE
             = new PSResource(PSResource.TYPE_ENCODING, "WinAnsiEncoding");
-    
+
     /**
      * Defines the WinAnsi encoding for use in PostScript files.
      * @param gen the PostScript generator
@@ -120,6 +125,42 @@ public class PSFontUtils {
         gen.getResourceTracker().registerSuppliedResource(WINANSI_ENCODING_RESOURCE);
     }
 
+    /** the PSResource representing the AdobeStandardCyrillicEncoding. */
+    public static final PSResource ADOBECYRILLIC_ENCODING_RESOURCE
+            = new PSResource(PSResource.TYPE_ENCODING, "AdobeStandardCyrillicEncoding");
+
+    /**
+     * Defines the AdobeStandardCyrillic encoding for use in PostScript files.
+     * @param gen the PostScript generator
+     * @throws IOException In case of an I/O problem
+     */
+    public static void defineAdobeCyrillicEncoding(PSGenerator gen) throws IOException {
+        gen.writeDSCComment(DSCConstants.BEGIN_RESOURCE, ADOBECYRILLIC_ENCODING_RESOURCE);
+        gen.writeln("/AdobeStandardCyrillicEncoding [");
+        for (int i = 0; i < Glyphs.ADOBECYRILLIC_ENCODING.length; i++) {
+            if (i > 0) {
+                if ((i % 5) == 0) {
+                    gen.newLine();
+                } else {
+                    gen.write(" ");
+                }
+            }
+            final char ch = Glyphs.ADOBECYRILLIC_ENCODING[i];
+            final String glyphname = Glyphs.charToGlyphName(ch);
+            if ("".equals(glyphname)) {
+                gen.write("/" + Glyphs.NOTDEF);
+            } else {
+                gen.write("/");
+                gen.write(glyphname);
+            }
+        }
+        gen.newLine();
+        gen.writeln("] def");
+        gen.writeDSCComment(DSCConstants.END_RESOURCE);
+        gen.getResourceTracker().registerSuppliedResource(ADOBECYRILLIC_ENCODING_RESOURCE);
+    }
+
+
     /**
      * Redefines the encoding of a font.
      * @param gen the PostScript generator
@@ -127,7 +168,7 @@ public class PSFontUtils {
      * @param encoding the new encoding (must be predefined in the PS file)
      * @throws IOException In case of an I/O problem
      */
-    public static void redefineFontEncoding(PSGenerator gen, String fontName, String encoding) 
+    public static void redefineFontEncoding(PSGenerator gen, String fontName, String encoding)
                 throws IOException {
         gen.writeln("/" + fontName + " findfont");
         gen.writeln("dup length dict begin");
