@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: Service.java 752408 2009-03-11 08:48:21Z jeremias $ */
+/* $Id: Service.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.util;
 
@@ -41,14 +41,18 @@ import org.apache.commons.io.IOUtils;
  * interface is very similar to the one they describe which seems to
  * be missing in the JDK.
  *
- * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: Service.java 752408 2009-03-11 08:48:21Z jeremias $
+ * @version $Id: Service.java 1345683 2012-06-03 14:50:33Z gadams $
+ *
+ * Originally authored by Thomas DeWeese.
  */
-public class Service {
+public final class Service {
+
+    private Service() {
+    }
 
     // Remember providers we have looked up before.
-    static Map classMap = new java.util.HashMap();
-    static Map instanceMap = new java.util.HashMap();
+    static Map<String, List<String>> classMap = new java.util.HashMap<String, List<String>>();
+    static Map<String, List<Object>> instanceMap = new java.util.HashMap<String, List<Object>>();
 
     /**
      * Returns an iterator where each element should implement the
@@ -61,8 +65,57 @@ public class Service {
      *
      * @param cls The class/interface to search for providers of.
      */
-    public static synchronized Iterator providers(Class cls) {
-        return providers(cls, true);
+    public static synchronized Iterator<Object> providers(Class<?> cls) {
+        String serviceFile = getServiceFilename(cls);
+
+        List<Object> l = instanceMap.get(serviceFile);
+        if (l != null) {
+            return l.iterator();
+        }
+
+        l = new java.util.ArrayList<Object>();
+        instanceMap.put(serviceFile, l);
+
+        ClassLoader cl = getClassLoader(cls);
+        if (cl != null) {
+            List<String> names = getProviderNames(cls, cl);
+            for (String name : names) {
+                try {
+                    // Try and load the class
+                    Object obj = cl.loadClass(name).newInstance();
+                    // stick it into our vector...
+                    l.add(obj);
+                } catch (Exception ex) {
+                    // Just try the next name
+                }
+            }
+        }
+        return l.iterator();
+    }
+
+    /**
+     * Returns an iterator where each element should be the name
+     * of a class that implements the
+     * interface (or subclass the baseclass) described by cls.  The
+     * Classes are found by searching the classpath for service files
+     * named: 'META-INF/services/&lt;fully qualified classname&gt; that list
+     * fully qualified classnames of classes that implement the
+     * service files classes interface.
+     *
+     * @param cls The class/interface to search for providers of.
+     */
+    public static synchronized Iterator<String> providerNames(Class<?> cls) {
+        String serviceFile = getServiceFilename(cls);
+
+        List<String> l = classMap.get(serviceFile);
+        if (l != null) {
+            return l.iterator();
+        }
+
+        l = new java.util.ArrayList<String>();
+        classMap.put(serviceFile, l);
+        l.addAll(getProviderNames(cls));
+        return l.iterator();
     }
 
     /**
@@ -70,25 +123,73 @@ public class Service {
      * interface (or subclass the baseclass) described by cls.  The
      * Classes are found by searching the classpath for service files
      * named: 'META-INF/services/&lt;fully qualified classname&gt; that list
-     * fully qualifted classnames of classes that implement the
+     * fully qualified classnames of classes that implement the
      * service files classes interface.  These classes must have
      * default constructors if returnInstances is true.
      *
+     * This is a deprecated, type-unsafe legacy method.
+     *
      * @param cls The class/interface to search for providers of.
      * @param returnInstances true if the iterator should return instances rather than class names.
+     * @deprecated use the type-safe methods providers(Class<?>) or providerNames(Class<?>) instead.
      */
-    public static synchronized Iterator providers(Class cls, boolean returnInstances) {
-        String serviceFile = "META-INF/services/" + cls.getName();
-        Map cacheMap = (returnInstances ? instanceMap : classMap);
+    public static Iterator<?> providers(Class<?> cls, boolean returnInstances) {
+        return (returnInstances ? providers(cls) : providerNames(cls));
+    }
 
-        List l = (List)cacheMap.get(serviceFile);
-        if (l != null) {
-            return l.iterator();
+    private static List<String> getProviderNames(Class<?> cls) {
+        return getProviderNames(cls, getClassLoader(cls));
+    }
+
+    private static List<String> getProviderNames(Class<?> cls, ClassLoader cl) {
+        List<String> l = new java.util.ArrayList<String>();
+
+        // No class loader so we can't find 'serviceFile'.
+        if (cl == null) {
+            return l;
         }
 
-        l = new java.util.ArrayList();
-        cacheMap.put(serviceFile, l);
+        Enumeration<URL> e;
+        try {
+            e = cl.getResources(getServiceFilename(cls));
+        } catch (IOException ioe) {
+            return l;
+        }
 
+        while (e.hasMoreElements()) {
+            try {
+                URL u = e.nextElement();
+
+                InputStream    is = u.openStream();
+                Reader         r  = new InputStreamReader(is, "UTF-8");
+                BufferedReader br = new BufferedReader(r);
+                try {
+                    for (String line = br.readLine(); line != null; line = br.readLine()) {
+                        // First strip any comment...
+                        int idx = line.indexOf('#');
+                        if (idx != -1) {
+                            line = line.substring(0, idx);
+                        }
+
+                        // Trim whitespace.
+                        line = line.trim();
+
+                        if (line.length() != 0) {
+                            l.add(line);
+                        }
+                    }
+                } finally {
+                    IOUtils.closeQuietly(br);
+                    IOUtils.closeQuietly(is);
+                }
+            } catch (Exception ex) {
+                // Just try the next file...
+            }
+        }
+        return l;
+    }
+
+    private static ClassLoader getClassLoader(Class<?> cls) {
         ClassLoader cl = null;
         try {
             cl = cls.getClassLoader();
@@ -102,69 +203,11 @@ public class Service {
         if (cl == null) {
             cl = ClassLoader.getSystemClassLoader();
         }
+        return cl;
+    }
 
-        // No class loader so we can't find 'serviceFile'.
-        if (cl == null) {
-            return l.iterator();
-        }
-
-        Enumeration e;
-        try {
-            e = cl.getResources(serviceFile);
-        } catch (IOException ioe) {
-            return l.iterator();
-        }
-
-        while (e.hasMoreElements()) {
-            try {
-                URL u = (URL)e.nextElement();
-
-                InputStream    is = u.openStream();
-                Reader         r  = new InputStreamReader(is, "UTF-8");
-                BufferedReader br = new BufferedReader(r);
-                try {
-                    String line = br.readLine();
-                    while (line != null) {
-                        try {
-                            // First strip any comment...
-                            int idx = line.indexOf('#');
-                            if (idx != -1) {
-                                line = line.substring(0, idx);
-                            }
-
-                            // Trim whitespace.
-                            line = line.trim();
-
-                            // If nothing left then loop around...
-                            if (line.length() == 0) {
-                                line = br.readLine();
-                                continue;
-                            }
-
-                            if (returnInstances) {
-                                // Try and load the class
-                                Object obj = cl.loadClass(line).newInstance();
-                                // stick it into our vector...
-                                l.add(obj);
-                            } else {
-                                l.add(line);
-                            }
-                        } catch (Exception ex) {
-                            // Just try the next line
-                        }
-                        line = br.readLine();
-                    }
-                } finally {
-                    IOUtils.closeQuietly(br);
-                    IOUtils.closeQuietly(is);
-                }
-            } catch (Exception ex) {
-                // Just try the next file...
-            } catch (LinkageError le) {
-                // Just try the next file...
-            }
-        }
-        return l.iterator();
+    private static String getServiceFilename(Class<?> cls) {
+        return "META-INF/services/" + cls.getName();
     }
 
 }
