@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-/* $Id: ASCII85OutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $ */
+/* $Id: ASCII85OutputStream.java 1345683 2012-06-03 14:50:33Z gadams $ */
 
 package org.apache.xmlgraphics.util.io;
 
-import java.io.OutputStream;
 import java.io.FilterOutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
 
 /**
  * This class applies a ASCII85 encoding to the stream.
  *
- * @version $Id: ASCII85OutputStream.java 750418 2009-03-05 11:03:54Z vhennebert $
+ * @version $Id: ASCII85OutputStream.java 1345683 2012-06-03 14:50:33Z gadams $
  */
 public class ASCII85OutputStream extends FilterOutputStream
             implements ASCII85Constants, Finalizable {
@@ -92,7 +92,8 @@ public class ASCII85OutputStream extends FilterOutputStream
             if (firstpart > 0) {
                 out.write(buf, 0, firstpart);
             }
-            out.write(EOL); bw++;
+            out.write(EOL);
+            bw++;
             int rest = len - firstpart;
             if (rest > 0) {
                 out.write(buf, firstpart, rest);
