@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: Metadata.java 606564 2007-12-23 15:42:28Z jeremias $ */
+/* $Id: Metadata.java 1130449 2011-06-02 09:30:51Z spepping $ */
 
 package org.apache.xmlgraphics.xmp;
 
@@ -44,33 +44,38 @@ public class Metadata implements XMLizable, PropertyAccess {
     public void setProperty(XMPProperty prop) {
         properties.put(prop.getName(), prop);
     }
-    
+
     /** {@inheritDoc} */
     public XMPProperty getProperty(String uri, String localName) {
         return getProperty(new QName(uri, localName));
     }
-    
+
     /** {@inheritDoc} */
     public XMPProperty getProperty(QName name) {
         XMPProperty prop = (XMPProperty)properties.get(name);
         return prop;
     }
-    
+
+    /** {@inheritDoc} */
+    public XMPProperty removeProperty(QName name) {
+        return (XMPProperty)properties.remove(name);
+    }
+
     /** {@inheritDoc} */
     public XMPProperty getValueProperty() {
         return getProperty(XMPConstants.RDF_VALUE);
     }
-    
+
     /** {@inheritDoc} */
     public int getPropertyCount() {
         return this.properties.size();
     }
-    
+
     /** {@inheritDoc} */
     public Iterator iterator() {
         return this.properties.keySet().iterator();
     }
-    
+
     /**
      * Merges this metadata object into a given target metadata object. The merge rule set provided
      * by each schema is used for the merge.
@@ -87,11 +92,13 @@ public class Metadata implements XMLizable, PropertyAccess {
             merger.merge(prop, target);
         }
     }
-    
+
     /** {@inheritDoc} */
     public void toSAX(ContentHandler handler) throws SAXException {
         AttributesImpl atts = new AttributesImpl();
+        handler.startPrefixMapping("x", XMPConstants.XMP_NAMESPACE);
         handler.startElement(XMPConstants.XMP_NAMESPACE, "xmpmeta", "x:xmpmeta", atts);
+        handler.startPrefixMapping("rdf", XMPConstants.RDF_NAMESPACE);
         handler.startElement(XMPConstants.RDF_NAMESPACE, "RDF", "rdf:RDF", atts);
         //Get all property namespaces
         Set namespaces = new java.util.HashSet();
@@ -109,7 +116,7 @@ public class Metadata implements XMLizable, PropertyAccess {
 
             boolean first = true;
             boolean empty = true;
-            
+
             Iterator props = properties.values().iterator();
             while (props.hasNext()) {
                 XMPProperty prop = (XMPProperty)props.next();
@@ -125,7 +132,7 @@ public class Metadata implements XMLizable, PropertyAccess {
                             handler.startPrefixMapping(prefix, ns);
                         }
                         handler.startElement(XMPConstants.RDF_NAMESPACE,
-                                "RDF", "rdf:Description", atts);
+                                "Description", "rdf:Description", atts);
                         empty = false;
                         first = false;
                     }
@@ -133,15 +140,17 @@ public class Metadata implements XMLizable, PropertyAccess {
                 }
             }
             if (!empty) {
-                handler.endElement(XMPConstants.RDF_NAMESPACE, "RDF", "rdf:Description");
+                handler.endElement(XMPConstants.RDF_NAMESPACE, "Description", "rdf:Description");
                 if (prefix != null) {
                     handler.endPrefixMapping(prefix);
                 }
             }
         }
-        
+
         handler.endElement(XMPConstants.RDF_NAMESPACE, "RDF", "rdf:RDF");
+        handler.endPrefixMapping("rdf");
         handler.endElement(XMPConstants.XMP_NAMESPACE, "xmpmeta", "x:xmpmeta");
+        handler.endPrefixMapping("x");
     }
 
 }
